@@ -27,6 +27,19 @@ const _collectDataToExport = () => {
 };
 
 const onConfigurationImport = async () => {
+    if (!isCommandDefault()) {
+        const response = await displayModal(
+            getTranslation('dynamic.modal.configModalTitle'),
+            getTranslation('dynamic.modal.configModalDescription'),
+            [
+                getTranslation('dynamic.modal.configModalConfirmButton'),
+                getTranslation('dynamic.modal.configModalCancelButton')
+            ]);
+
+        if (response !== getTranslation('dynamic.modal.configModalConfirmButton'))
+            return;
+    }
+
     const data = await eel.import_configuration()();
     importConfiguration(data);
 };
